ytree\.arbor\.frontends\.tree\_farm\.arbor\.TreeFarmArbor
=========================================================

.. currentmodule:: ytree.arbor.frontends.tree_farm.arbor

.. autoclass:: TreeFarmArbor

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TreeFarmArbor.__init__
      ~TreeFarmArbor.add_alias_field
      ~TreeFarmArbor.add_analysis_field
      ~TreeFarmArbor.add_derived_field
      ~TreeFarmArbor.is_grown
      ~TreeFarmArbor.is_setup
      ~TreeFarmArbor.save_arbor
      ~TreeFarmArbor.select_halos
      ~TreeFarmArbor.set_selector
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TreeFarmArbor.arr
      ~TreeFarmArbor.box_size
      ~TreeFarmArbor.field_info
      ~TreeFarmArbor.hubble_constant
      ~TreeFarmArbor.quan
      ~TreeFarmArbor.size
      ~TreeFarmArbor.trees
      ~TreeFarmArbor.unit_registry
   
   